<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-svp?lang_cible=pt_br
// ** ne pas modifier le fichier **

return [

	// S
	'svp_description' => 'Este plugin fornece, por um lado, uma API que permite fazer buscas culti-critérios, coletar e apresentar as informações sobre os plugins SPIP (módulos funcionais, temas e templates) e, por outro lado, uma nova interface de administração dos plugins, gerenciando as dependências entre plugins.',
	'svp_slogan' => 'Servidor de informações e transferência de Plugins',
];
